@ECHO OFF
GOTO START


Program name:
=============
        Tic2Dir.Bat -- requires a config file (see "About the .CFG file",
                       below) and valid TIC files.

Purpose:
--------
	Process TIC files, using 'Area' keyword matching, to move the
        associated files to defined target directories.

Parameters required:
--------------------
        %1 -------- inbound TIC file name.
        %2 -------- path to a CFG file.

        %3 -------- optional action to be taken with the TIC, when done:
                    *> KEEP it
                    *> KILL the TIC file
                    + The default is to KEEP it.

Uses these dependencies:
------------------------
	FIND.EXE -- a supplied MS-DOS utility.
	NSET.COM -- another free utility by Horst Schaeffer.
        MOVE.EXE -- a supplied MS-DOS utility.

Limitations:
------------
        *MOST Important* ----- Tic2Dir.Bat _will_ only handle nine (9)
                               file areas.  If you need more, then get
                               a decent TIC handler.  It is really only
                               made for use by point-sized operators.

        ! W A R N I N G ! ---- Use beyond nine (9) areas _will_ produce
        =================      unpredictable results.

About the .CFG file:
--------------------
        *Important* ----- this file is a plain ASCII text file, consisting
                          of file area 'tags' and target area directory
                          names.

        Example: my Tic2Dir.Cfg file -
     -----8<-----C-U-T--H-E-R-E----->8-----
     NODEDIFF=D:\ARCS\GENERAL
     FIDONEWS=D:\ARCS\FIDONEWS
     Z3-ELIST=D:\ARCS\GENERAL
     BFDS=D:\ARCS\DOS\UTILS
     FASTECHO=D:\ARCS\BBSUTILS
     -----8<-----C-U-T--H-E-R-E----->8-----

        The name of the CFG file is _un_important.  Be creative!  :-)

Pseudocode:
-----------
  FIND the string "Area" in the .TIC obtaining [line#1]
  use NSET with [line#1] to obtain the area 'tag' name in the .TIC
  FIND string "File" in the .TIC and get [line#2]
  use NSET with [line#2] to get the file's name in the .TIC
  FIND the tag in TIC2DIR.CFG, obtaining the target dir in TIC2DIR.CFG
  MOVE the associated file to the target directory
  Do we KEEP or KILL the incoming TIC file - default is to KEEP.

Operating system:
-----------------
	I _know_ Tic2Dir works in MS-DOS 7.01, under the Win95B GUI.

        Please let me know if it works in any other OS environment.



::                          ---===[ * * * ]===---
:START
  ECHO.
  ECHO  %0 [ver 1.05.00]
  ECHO.
  ECHO  Processes TIC-associated files, using 'Area' keyword matching.
  ECHO.


  :: ************************ Initialize local environment.
  :: Variables.
  SET T_TEST=TICFILE
  SET T_NBR1=0123
  SET T_NBR2=0123
  SET T_TAGN=TAG
  SET T_FILE=FILENAME
  SET T_TGET=TGT_DIR
  SET T_KEEP=KEEP
  SET T_BASE=TICBAK


  :: ************************* Check the command-line info.
  :: Maybe somone wants help, first.
  for %%f in (h H ?) do if "%1"=="/%%f" goto HELP
  for %%f in (h H ?) do if "%1"=="-%%f" goto HELP
  for %%f in (h H ?) do if "%1"=="%%f" goto HELP


  :: Simple checks for the required _number_ of params.
  IF [NO%1PARAM]==[NOPARAM] GOTO HOWTOUSE
  IF [NO%2PARAM]==[NOPARAM] GOTO HOWTOUSE


  :: Check to make sure param #1 is in fact a TIC file.
  DIR %1 /B | NSET /S. T_TEST=$1
  IF NOT EXIST %T_TEST%.TIC GOTO HOWTOUSE


  :: Do we have the CFG file nominated, actually in the path specified.
  IF NOT EXIST %2 GOTO HOWTOUSE


  :: Convert the 3rd param (if there is one) to uppercase for testing.
  IF NOT [NO%3PARAM]==[NOPARAM] ECHO %3 | NSET /U T_KEEP=$0


  :: ************************** This is it, step-by-step.
  :: FIND the string "Area" in the .TIC obtaining [line#1]
  FIND /N /I "Area" %1
  IF ERRORLEVEL 1 GOTO EL_ERR_1
  FIND /N /I "Area" %1 | NSET /P2,1 /L3 T_NBR1=$1
  IF ERRORLEVEL 1 GOTO EL_ERR_1


  :: use NSET with [line#1] to obtain the area 'tag' name in the .TIC
  NSET /L%T_NBR1% T_TAGN=$2 <%1
  IF ERRORLEVEL 1 GOTO EL_ERR_1


  :: FIND string "File" in the .TIC and get [line#2]
  FIND /N /I "File" %1
  IF ERRORLEVEL 1 GOTO EL_ERR_1
  FIND /N /I "File" %1 | NSET /P2,1 /L3 T_NBR2=$1
  IF ERRORLEVEL 1 GOTO EL_ERR_1


  :: use NSET with [line#2] to get the file's name in the .TIC
  NSET /L%T_NBR2% T_FILE=$2 <%1
  IF ERRORLEVEL 1 GOTO EL_ERR_1
  IF NOT EXIST %T_FILE% GOTO ERR_MSG_1


  :: FIND the tag in TIC2DIR.CFG, obtaining the target dir in TIC2DIR.CFG
  FIND /N /I "%T_TAGN%" <%2
  IF ERRORLEVEL 1 GOTO EL_ERR_1
  FIND /N /I "%T_TAGN%" <%2 | NSET T_TGET=$2
  IF ERRORLEVEL 1 GOTO EL_ERR_1
  IF NOT EXIST %T_TGET%\NUL GOTO ERR_MSG_1


  :: MOVE the associated file to the target dir.
  MOVE /Y %T_FILE% %T_TGET%


  :: Are we KILL-ing the TIC file?
    IF [%T_KEEP%]==[KILL] DEL %1
    IF [%T_KEEP%]==[KILL] GOTO STOPHERE
  :: Okay, then we must be KEEP-ing it.
    :: Determine a suitable filename, first, using the base filename of
    :: the TIC-attached file.
    ECHO %T_FILE% | NSET /S. T_BASE=$1
    REN %1 %T_BASE%.TAC
  GOTO STOPHERE


  :: *********** General-purpose error trapper for FIND/NSET
  :EL_ERR_1
    :: Each FIND has been replicated, to trap for ErrorLevel 1 or higher,
    :: which indicates an error sufficient to require a halt.
    :: NSET also uses an exit code (errorlevel) of 1, to indicate failure.
    Echo.
    Echo Cannot continue; an error occurred in either FIND or NSET.
    Echo.
    Echo The problem TIC and its associated file will remain un-touched in
    Echo the current directory.  %0 is now stopping...
    Echo.
  GOTO STOPHERE


  :: ************************** File/directory 'existence' error trap
  :ERR_MSG_1
    :: We've tested for the existence of a file or directory and DOS has
    :: come up empty-handed.
    Echo.
    Echo Cannot find the TIC-associated file =or= the target directory!
    Echo.
  GOTO STOPHERE


  :: ***************************** HELP!!!!!!!
  :HELP
    ECHO  %0 requires a config file and valid TIC files.  The config
    ECHO  file is a plain ASCII text file, consisting of file area 'tags'
    ECHO  and target directory paths.  (E.g., NODEDIFF=D:\ARCS\NODEDIFF)
    ECHO.
    ECHO  !WARNING! %0 can _only_ handle nine (9) file area 'tag' lines.
    ECHO.
    ECHO  Optionally KEEPs or KILLs the .TIC file when processing is done.
    ECHO.
    ECHO  The following (external) utilities _must_ be available on the DOS
    ECHO  search PATH -
    ECHO        FIND.EXE -- a supplied MS-DOS utility.
    ECHO        NSET.COM -- another free utility by Horst Schaeffer.
    ECHO        MOVE.EXE -- a supplied MS-DOS utility.
    ECHO.
  GOTO HOWTOUSE


  :: ************************* Assist the unsuspecting user
  :HOWTOUSE
    ECHO  Usage is: %0  Inbound.TIC  Path_to_.CFG_File  [KEEP/KILL]  c/r
    ECHO.
  GOTO STOPHERE


:: ******************************* End of the line, baby.
:STOPHERE
  :: Clean out local environment.
  SET T_TEST=
  SET T_NBR1=
  SET T_NBR2=
  SET T_TAGN=
  SET T_FILE=
  SET T_TGET=
  SET T_KEEP=
  SET T_BASE=
:: (Wish I could just say RELEASE ALL LIKE T_* just as in dBASE.)
:: All done; exit, stop, quit, finito, ciao...
C:\



::                          ---===[ * * * ]===---
:: Tic2Dir is free!  Enjoy!  =8-)  (c)1999 Paul D. Quinn
::   FidoNet: 3:640/384.0, e-mail: eskimo261@bigfoot.com -- 13 November 1999.

:: Direct assistance from NSET's author, Horst Schaeffer, is acknowledged
:: and very much appreciated.  Thanks Horst!